calorine
========

**calorine** is a Python library for constructing and sampling neuroevolution potentials (NEPs) via `GPUMD <https://gpumd.zheyongfan.org/>`_.
It provides ASE calculators, IO functions for reading and writing GPUMD input and output files, as well as a Python interface that allows inspection NEP models.
The documentation can be found at https://calorine.materialsmodeling.org/.
